import time, os
from pathlib import Path
import pandas as pd
from collections import deque
from pyvpsolver.solvers import mvpsolver

def generate_data(mcc, mcm, mcd, mcn, ctc, ctm, ctd, ctn):
    total_mc = len(mcc)
    total_ct = len(ctc)

    data = {}
    # Bins
    bin_capacities = deque()
    cost = deque([1 for _ in range(total_mc)])
    num_bins = deque([1 for _ in range(total_mc)])

    for i in range(total_mc):
        bin_capacities.appendleft([int(mcc[i]), int(mcm[i]), int(mcd[i]), int(mcn[i])])

    # Items
    item_capacities = deque()
    demand = deque([1 for _ in range(total_ct)])

    for i in range(total_ct):
        item_capacities.appendleft([[int(ctc[i]), int(ctm[i]), int(ctd[i]), int(ctn[i])]])

    data['bin_capacities'] = bin_capacities
    data['cost'] = cost
    data['num_bins'] = num_bins
    data['item_capacities'] = item_capacities
    data['demand'] = demand
    return data

if __name__ == '__main__':

    abra = pd.read_csv('demo_m.csv')
    kdabra = pd.read_csv('demo_c.csv')

    mcc = abra['c']
    mcm = abra['m']
    mcd = abra['d']
    mcn = abra['n']

    ctc = kdabra['c']
    ctm = kdabra['m']
    ctd = kdabra['d']
    ctn = kdabra['n']    

    data = generate_data(mcc, mcm, mcd, mcn, ctc, ctm, ctd, ctn)
    # print_data(data)

    solution = mvpsolver.solve(
                data['bin_capacities'], data['cost'], data['num_bins'],
                data['item_capacities'], data['demand'],
                script='vpsolver_scip.sh',
                verbose=True    
            )

    mvpsolver.print_solution(solution)    
